Is this for me?
===============

CAPPr is for you if you:

#. Want to do text classification, i.e., you want an LLM to pick from a list of choices

#. Can locally load an LLM using Hugging Face or Llama CPP Python, or pay to use an
   OpenAI `/v1/completions
   <https://platform.openai.com/docs/models/model-endpoint-compatibility>`_ model
   (`excluding
   <https://cappr.readthedocs.io/en/latest/select_a_language_model.html#openai>`_
   ``gpt-3.5-turbo-instruct``).
